{
    "scan": {
        "analyzer-version-clippy": "1.92.0",
        "analyzer-version-cppcheck": "2.19.1",
        "analyzer-version-gcc": "16.0.0",
        "analyzer-version-gcc-analyzer": "16.0.0",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-139.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20250521.132812.g8eff701.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "tmt-1.65.0.dev15+g1af4d82c3-main",
        "store-results-to": "/tmp/tmpj34cyuxc/tmt-1.65.0.dev15+g1af4d82c3-main.tar.xz",
        "time-created": "2026-01-13 15:27:22",
        "time-finished": "2026-01-13 15:29:11",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'gcc,cppcheck,clippy,shellcheck,unicontrol' '-o' '/tmp/tmpj34cyuxc/tmt-1.65.0.dev15+g1af4d82c3-main.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpj34cyuxc/tmt-1.65.0.dev15+g1af4d82c3-main.src.rpm'",
        "tool-version": "csmock-3.8.3.20251215.161544.g62de9a5-1.el9"
    },
    "defects": [
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "f6e570d155698d640842c8c008337ce6a7b95653",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/tmt-1.65.0.dev15+g1af4d82c3-build/BUILDROOT/usr/share/doc/tmt/examples/convert/runtest.sh",
                    "line": 20,
                    "column": 22,
                    "h_size": 7,
                    "event": "warning[SC2154]",
                    "message": "TmpDir is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   18|           rlAssertRpm $PACKAGE",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   19|           rlRun \"TmpDir=\\$(mktemp -d)\" 0 \"Creating tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   20|->         rlRun \"pushd $TmpDir\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   21|   \t\trlRun \"set -o pipefail\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   22|       rlPhaseEnd",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "51d50199495e5d21064ed82889dc61497f72f365",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/tmt-1.65.0.dev15+g1af4d82c3-build/BUILDROOT/usr/share/doc/tmt/examples/wow/full/test.sh",
                    "line": 8,
                    "column": 22,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "tmp is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    6|           rlRun \"tmp=\\$(mktemp -d)\" 0 \"Create tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    7|           rlRun \"run=/var/tmp/tmt/mini\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    8|->         rlRun \"pushd $tmp\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    9|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   10|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "df69818168fbdc8d25c2acef23d94af019e83c39",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/tmt-1.65.0.dev15+g1af4d82c3-build/BUILDROOT/usr/share/doc/tmt/examples/wow/full/test.sh",
                    "line": 22,
                    "column": 27,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "run is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   20|           report=\"$BEAKERLIB_COMMAND_REPORT_RESULT\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   21|           export BEAKERLIB_COMMAND_REPORT_RESULT=/bin/true",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   22|->         rlRun \"tmt run -i $run -av \\",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   23|               prepare -h install -c psss/tmt -p tmt+all \\",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   24|               plan --name 'plans|container|virtual'\"",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "6b4b5f91f191a95b0501bf604bb0aa3ee3292094",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/tmt-1.65.0.dev15+g1af4d82c3-build/BUILDROOT/usr/share/doc/tmt/examples/wow/mini/test.sh",
                    "line": 8,
                    "column": 22,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "tmp is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    6|           rlRun \"tmp=\\$(mktemp -d)\" 0 \"Create tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    7|           rlRun \"run=/var/tmp/tmt/mini\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    8|->         rlRun \"pushd $tmp\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    9|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   10|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "d0e4620fff17928ecebcb2e6709383a4c2e040b9",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/tmt-1.65.0.dev15+g1af4d82c3-build/BUILDROOT/usr/share/doc/tmt/examples/wow/mini/test.sh",
                    "line": 14,
                    "column": 27,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "run is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   12|           rlRun \"dnf install -y tmt\" 0 \"Install the base tmt package\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   13|           rlRun \"tmt init -t base\" 0 \"Initialize with the base template\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   14|->         rlRun \"tmt run -i $run -av provision -h local\" 0 \"Run the example\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   15|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   16|   ",
                    "verbosity_level": 1
                }
            ]
        }
    ]
}
